{%extends "base.html" %}

{% block title %}Reports{% endblock %}

{% block body %}
<form method="POST">

    <h2>Output Folder</h2>
    <input name="output_dir" placeholder="C:\Users\j.gajardo">

    <h2>Select the kind of query</h2>
    <select name="kind_of_query">
        <option>=select option=</option>
        <option value="vertica">Vertica</option>
        <option value="hive" disabled>Hive</option>
    </select>



    <h2>Select periodicity</h2>
    days: <input name="days">

    <br>
    weekdays:
    Monday <input type="checkbox" name="monday"> |
    Tuesday <input type="checkbox" name="tuesday"> |
    Wednesday <input type="checkbox" name="wednesday"> |
    Thursday <input type="checkbox" name="thursday"> |
    Friday <input type="checkbox" name="friday">|
    Saturday <input type="checkbox" name="saturday">|
    Sunday <input type="checkbox" name="sunday">

    <br>
    months:
    Jan <input type="checkbox" name="jan"> |
    Feb <input type="checkbox" name="feb"> |
    Mar <input type="checkbox" name="mar"> |
    Apr <input type="checkbox" name="apr"> |
    May <input type="checkbox" name="may"> |
    Jun <input type="checkbox" name="jun"> |
    Jul <input type="checkbox" name="jul"> |
    Aug <input type="checkbox" name="aug"> |
    Sep <input type="checkbox" name="sep"> |
    Oct <input type="checkbox" name="oct"> |
    Nov <input type="checkbox" name="nov"> |
    Dec <input type="checkbox" name="dec">


    <h2>Select output file type</h2>
    <select name="output_type">
        <option>=select option=</option>
        <option value="csv">csv</option>
        <option value="excel">excel</option>
    </select>

    <h2>Destination Email</h2>
    <input name="destination_email" placeholder="user@criteo.com">

    <h2>Email Subject</h2>
    <input name="subject_email">

    <h2>Email Body</h2>
    <textarea name="body_email" rows="5" cols="50"></textarea>

    <h2>Error Email</h2>
    <input required name="error_email" placeholder="user@criteo.com">



    <h2>Query</h2>
    <textarea name="query" rows="20" cols="50"></textarea>
    <br>
    <input type="submit" value="save">
</form>

<!--
<br>
<form><input type="submit" value="test query"></form>

<br>
<form><input type="submit" value="download example report"></form>
-->
{% endblock %}

